{% load el_pagination_tags %}

{% paginate 5 items using "items-page" %}
{% for item in items %}
  <div class="well item">
    <h4>{{ item.title }}</h4>
    {{ item.contents }}
  </div>
{% endfor %}
{% show_more "More results" %}
